@@ -11,6 +11,7 @@ from ast import And as NodeAnd
 from ast import AnnAssign as NodeAnnAssign
 from ast import Assign as NodeAssign
 from ast import Attribute as NodeAttribute
+from ast import AugAssign as NodeAugAssign
 from ast import BinOp as NodeBinOp
 from ast import BitAnd as NodeBitAnd
 from ast import BitOr as NodeBitOr
@@ -70,6 +71,7 @@ from ast import alias as NodeAlias
 from ast import arguments as NodeArguments
 from ast import comprehension as NodeComprehension
 from ast import keyword as NodeKeyword
+from contextlib import suppress
 from functools import partial
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, Sequence, Type
@@ -77,6 +79,9 @@ from typing import TYPE_CHECKING, Any, Callable, Sequence, Type
 from griffe.collections import LinesCollection
 from griffe.exceptions import LastNodeError, RootNodeError
 from griffe.expressions import Expression, Name
+from griffe.logger import LogLevel, get_logger
+
+logger = get_logger(__name__)
 
 # TODO: remove once Python 3.7 support is dropped
 if sys.version_info < (3, 8):
@@ -89,6 +94,7 @@ else:
 
 # TODO: remove once Python 3.8 support is dropped
 if sys.version_info < (3, 9):
+    from ast import ExtSlice as NodeExtSlice
     from ast import Index as NodeIndex
 
 if TYPE_CHECKING:
@@ -522,31 +528,76 @@ def _join(sequence, item):
     return new_sequence
 
 
+def _parse__all__constant(node: NodeConstant, parent: Module) -> list[str]:
+    try:
+        return [node.value]
+    except AttributeError:
+        return [node.s]  # TODO: remove once Python 3.7 is dropped
+
+
+def _parse__all__name(node: NodeName, parent: Module) -> list[Name]:
+    return [Name(node.id, partial(parent.resolve, node.id))]
+
+
+def _parse__all__starred(node: NodeStarred, parent: Module) -> list[str | Name]:
+    return _parse__all__(node.value, parent)
+
+
+def _parse__all__sequence(node: NodeList | NodeSet | NodeTuple, parent: Module) -> list[str | Name]:
+    sequence = []
+    for elt in node.elts:
+        sequence.extend(_parse__all__(elt, parent))
+    return sequence
+
+
+def _parse__all__binop(node: NodeBinOp, parent: Module) -> list[str | Name]:
+    left = _parse__all__(node.left, parent)
+    right = _parse__all__(node.right, parent)
+    return left + right
+
+
+_node__all__map: dict[Type, Callable[[Any, Module], list[str | Name]]] = {  # noqa: WPS234
+    NodeConstant: _parse__all__constant,  # type: ignore[dict-item]
+    NodeName: _parse__all__name,  # type: ignore[dict-item]
+    NodeStarred: _parse__all__starred,
+    NodeList: _parse__all__sequence,
+    NodeSet: _parse__all__sequence,
+    NodeTuple: _parse__all__sequence,
+    NodeBinOp: _parse__all__binop,
+}
+
+# TODO: remove once Python 3.7 support is dropped
 if sys.version_info < (3, 8):
 
-    def parse__all__(node: NodeAssign) -> set[str]:  # noqa: WPS116,WPS120
-        """Get the values declared in `__all__`.
+    def _parse__all__nameconstant(node: NodeNameConstant, parent: Module) -> list[Name]:
+        return [node.value]
 
-        Parameters:
-            node: The assignment node.
+    def _parse__all__str(node: NodeStr, parent: Module) -> list[str]:
+        return [node.s]
 
-        Returns:
-            A set of names.
-        """
-        return {elt.s for elt in node.value.elts}  # type: ignore[attr-defined]
+    _node__all__map[NodeNameConstant] = _parse__all__nameconstant  # type: ignore[assignment]
+    _node__all__map[NodeStr] = _parse__all__str  # type: ignore[assignment]
 
-else:
 
-    def parse__all__(node: NodeAssign) -> set[str]:  # noqa: WPS116,WPS120,WPS440
-        """Get the values declared in `__all__`.
+def _parse__all__(node: AST, parent: Module) -> list[str | Name]:
+    return _node__all__map[type(node)](node, parent)
 
-        Parameters:
-            node: The assignment node.
 
-        Returns:
-            A set of names.
-        """
-        return {elt.value for elt in node.value.elts}  # type: ignore[attr-defined]
+def parse__all__(node: NodeAssign | NodeAugAssign, parent: Module) -> list[str | Name]:  # noqa: WPS120,WPS440
+    """Get the values declared in `__all__`.
+
+    Parameters:
+        node: The assignment node.
+        parent: The parent module.
+
+    Returns:
+        A set of names.
+    """
+    try:
+        return _parse__all__(node.value, parent)
+    except KeyError as error:
+        logger.debug(f"Cannot parse __all__ assignment: {get_value(node.value)} ({error})")
+        return []
 
 
 # ==========================================================
@@ -576,8 +627,8 @@ def _get_bitor_annotation(node: NodeBitOr, parent: Module | Class) -> str:
 
 
 def _get_call_annotation(node: NodeCall, parent: Module | Class) -> Expression:
-    posargs = Expression(*[_get_annotation(arg, parent) for arg in node.args])
-    kwargs = Expression(*[_get_annotation(kwarg, parent) for kwarg in node.keywords])
+    posargs = Expression(*_join([_get_annotation(arg, parent) for arg in node.args], ", "))
+    kwargs = Expression(*_join([_get_annotation(kwarg, parent) for kwarg in node.keywords], ", "))
     args: Expression | str
     if posargs and kwargs:
         args = Expression(posargs, ", ", kwargs)
@@ -590,7 +641,14 @@ def _get_call_annotation(node: NodeCall, parent: Module | Class) -> Expression:
     return Expression(_get_annotation(node.func, parent), "(", args, ")")
 
 
-def _get_constant_annotation(node: NodeConstant, parent: Module | Class) -> str:
+def _get_constant_annotation(node: NodeConstant, parent: Module | Class) -> str | Name:
+    if isinstance(node.value, str):
+        node.id = node.value  # type: ignore[attr-defined]  # fake node as Name
+        return _get_name_annotation(node, parent)  # type: ignore[arg-type]
+    return _get_literal_annotation(node, parent)
+
+
+def _get_literal_annotation(node: NodeConstant, parent: Module | Class) -> str:
     return {type(...): lambda _: "..."}.get(type(node.value), repr)(node.value)
 
 
@@ -612,6 +670,10 @@ def _get_invert_annotation(node: NodeInvert, parent: Module | Class) -> str:
     return "~"
 
 
+def _get_keyword_annotation(node: NodeKeyword, parent: Module | Class) -> Expression:
+    return Expression(f"{node.arg}=", _get_annotation(node.value, parent))
+
+
 def _get_list_annotation(node: NodeList, parent: Module | Class) -> Expression:
     return Expression("[", *_join([_get_annotation(el, parent) for el in node.elts], ", "), "]")
 
@@ -622,7 +684,12 @@ def _get_name_annotation(node: NodeName, parent: Module | Class) -> Name:
 
 def _get_subscript_annotation(node: NodeSubscript, parent: Module | Class) -> Expression:
     left = _get_annotation(node.value, parent)
-    subscript = _get_annotation(node.slice, parent)
+    if left.full == "typing.Literal":  # type: ignore[union-attr]
+        _node_annotation_map[NodeConstant] = _get_literal_annotation
+        subscript = _get_annotation(node.slice, parent)
+        _node_annotation_map[NodeConstant] = _get_constant_annotation
+    else:
+        subscript = _get_annotation(node.slice, parent)
     return Expression(left, "[", subscript, "]")
 
 
@@ -634,6 +701,14 @@ def _get_unaryop_annotation(node: NodeUnaryOp, parent: Module | Class) -> Expres
     return Expression(_get_annotation(node.op, parent), _get_annotation(node.operand, parent))
 
 
+def _get_uadd_annotation(node: NodeUAdd, parent: Module | Class) -> str:
+    return "+"
+
+
+def _get_usub_annotation(node: NodeUSub, parent: Module | Class) -> str:
+    return "-"
+
+
 _node_annotation_map: dict[Type, Callable[[Any, Module | Class], str | Name | Expression]] = {
     NodeAttribute: _get_attribute_annotation,
     NodeBinOp: _get_binop_annotation,
@@ -644,11 +719,14 @@ _node_annotation_map: dict[Type, Callable[[Any, Module | Class], str | Name | Ex
     NodeEllipsis: _get_ellipsis_annotation,
     NodeIfExp: _get_ifexp_annotation,
     NodeInvert: _get_invert_annotation,
+    NodeKeyword: _get_keyword_annotation,
     NodeList: _get_list_annotation,
     NodeName: _get_name_annotation,
     NodeSubscript: _get_subscript_annotation,
     NodeTuple: _get_tuple_annotation,
     NodeUnaryOp: _get_unaryop_annotation,
+    NodeUAdd: _get_uadd_annotation,
+    NodeUSub: _get_usub_annotation,
 }
 
 # TODO: remove once Python 3.8 support is dropped
@@ -662,13 +740,22 @@ if sys.version_info < (3, 9):
 # TODO: remove once Python 3.7 support is dropped
 if sys.version_info < (3, 8):
 
-    def _get_nameconstant_annotation(node: NodeNameConstant, parent: Module | Class) -> str | Name | Expression:
+    def _get_bytes_annotation(node: NodeBytes, parent: Module | Class) -> str:
+        return repr(node.s)
+
+    def _get_nameconstant_annotation(node: NodeNameConstant, parent: Module | Class) -> str:
         return repr(node.value)
 
-    def _get_str_annotation(node: NodeStr, parent: Module | Class) -> str:
-        return node.s
+    def _get_num_annotation(node: NodeNum, parent: Module | Class) -> str:
+        return repr(node.n)
 
+    def _get_str_annotation(node: NodeStr, parent: Module | Class) -> str | Name:
+        node.value = node.s  # type: ignore[attr-defined]  # fake node as constant
+        return _node_annotation_map[NodeConstant](node, parent)  # type: ignore[return-value]
+
+    _node_annotation_map[NodeBytes] = _get_bytes_annotation
     _node_annotation_map[NodeNameConstant] = _get_nameconstant_annotation
+    _node_annotation_map[NodeNum] = _get_num_annotation
     _node_annotation_map[NodeStr] = _get_str_annotation
 
 
@@ -691,6 +778,33 @@ def get_annotation(node: AST | None, parent: Module | Class) -> str | Name | Exp
     return _get_annotation(node, parent)
 
 
+def safe_get_annotation(
+    node: AST | None,
+    parent: Module | Class,
+    log_level: LogLevel = LogLevel.error,
+) -> str | Name | Expression | None:
+    """Safely (no exception) extract a resolvable annotation.
+
+    Parameters:
+        node: The annotation node.
+        parent: The parent used to resolve the name.
+        log_level: Log level to use to log a message.
+
+    Returns:
+        A string or resovable name or expression.
+    """
+    try:
+        return get_annotation(node, parent)
+    except Exception as error:
+        message = f"Failed to parse annotation from '{node.__class__.__name__}' node"
+        with suppress(Exception):
+            message += f" at {parent.relative_filepath}:{node.lineno}"  # type: ignore[union-attr]
+        if not isinstance(error, KeyError):
+            message += f": {error}"
+        getattr(logger, log_level.value)(message)
+        return None
+
+
 # ==========================================================
 # docstrings
 def get_docstring(
@@ -716,14 +830,20 @@ def get_docstring(
     if isinstance(doc, NodeConstant) and isinstance(doc.value, str):
         return doc.value, doc.lineno, doc.end_lineno  # type: ignore[attr-defined]
     if isinstance(doc, NodeStr):
-        return doc.s, doc.lineno, doc.end_lineno  # type: ignore[attr-defined]
+
+        # TODO: remove once Python 3.7 support is dropped
+        # on Python 3.7, lineno seems to be the ending line of the string
+        # rather than the starting one, so we substract the number of newlines
+        lineno = doc.lineno
+        if sys.version_info < (3, 8):
+            lineno -= doc.s.count("\n")
+
+        return doc.s, lineno, doc.end_lineno  # type: ignore[attr-defined]
     return None, None, None
 
 
 # ==========================================================
 # values
-
-
 def _get_add_value(node: NodeAdd) -> str:
     return "+"
 
@@ -737,11 +857,11 @@ def _get_arguments_value(node: NodeArguments) -> str:
 
 
 def _get_attribute_value(node: NodeAttribute) -> str:
-    return f"{get_value(node.value)}.{node.attr}"
+    return f"{_get_value(node.value)}.{node.attr}"
 
 
 def _get_binop_value(node: NodeBinOp) -> str:
-    return f"{get_value(node.left)} {get_value(node.op)} {get_value(node.right)}"
+    return f"{_get_value(node.left)} {_get_value(node.op)} {_get_value(node.right)}"
 
 
 def _get_bitor_value(node: NodeBitOr) -> str:
@@ -757,12 +877,12 @@ def _get_bitxor_value(node: NodeBitXor) -> str:
 
 
 def _get_boolop_value(node: NodeBoolOp) -> str:
-    return get_value(node.op).join(get_value(value) for value in node.values)
+    return _get_value(node.op).join(_get_value(value) for value in node.values)
 
 
 def _get_call_value(node: NodeCall) -> str:
-    posargs = ", ".join(get_value(arg) for arg in node.args)
-    kwargs = ", ".join(get_value(kwarg) for kwarg in node.keywords)
+    posargs = ", ".join(_get_value(arg) for arg in node.args)
+    kwargs = ", ".join(_get_value(kwarg) for kwarg in node.keywords)
     if posargs and kwargs:
         args = f"{posargs}, {kwargs}"
     elif posargs:
@@ -771,20 +891,20 @@ def _get_call_value(node: NodeCall) -> str:
         args = kwargs
     else:
         args = ""
-    return f"{get_value(node.func)}({args})"
+    return f"{_get_value(node.func)}({args})"
 
 
 def _get_compare_value(node: NodeCompare) -> str:
-    left = get_value(node.left)
-    ops = [get_value(op) for op in node.ops]
-    comparators = [get_value(comparator) for comparator in node.comparators]
+    left = _get_value(node.left)
+    ops = [_get_value(op) for op in node.ops]
+    comparators = [_get_value(comparator) for comparator in node.comparators]
     return f"{left} " + " ".join(f"{op} {comp}" for op, comp in zip(ops, comparators))
 
 
 def _get_comprehension_value(node: NodeComprehension) -> str:
-    target = get_value(node.target)
-    iterable = get_value(node.iter)
-    conditions = [get_value(condition) for condition in node.ifs]
+    target = _get_value(node.target)
+    iterable = _get_value(node.iter)
+    conditions = [_get_value(condition) for condition in node.ifs]
     value = f"for {target} in {iterable}"
     if conditions:
         value = f"{value} if " + " if ".join(conditions)
@@ -797,20 +917,22 @@ def _get_constant_value(node: NodeConstant) -> str:
     return repr(node.value)
 
 
-def _get_constant_value_no_repr(node: NodeConstant) -> str:
-    return node.value
+def _get_constant_value_no_string_repr(node: NodeConstant) -> str:
+    if isinstance(node.value, str):
+        return node.value
+    return repr(node.value)
 
 
 def _get_dict_value(node: NodeDict) -> str:
     pairs = zip(node.keys, node.values)
-    gen = (f"{'None' if key is None else get_value(key)}: {get_value(value)}" for key, value in pairs)  # noqa: WPS509
+    gen = (f"{'None' if key is None else _get_value(key)}: {_get_value(value)}" for key, value in pairs)  # noqa: WPS509
     return "{" + ", ".join(gen) + "}"
 
 
 def _get_dictcomp_value(node: NodeDictComp) -> str:
-    key = get_value(node.key)
-    value = get_value(node.value)
-    generators = [get_value(gen) for gen in node.generators]
+    key = _get_value(node.key)
+    value = _get_value(node.value)
+    generators = [_get_value(gen) for gen in node.generators]
     return f"{{{key}: {value} " + " ".join(generators) + "}"
 
 
@@ -831,12 +953,12 @@ def _get_floordiv_value(node: NodeFloorDiv) -> str:
 
 
 def _get_formatted_value(node: NodeFormattedValue) -> str:
-    return f"{{{get_value(node.value)}}}"
+    return f"{{{_get_value(node.value)}}}"
 
 
 def _get_generatorexp_value(node: NodeGeneratorExp) -> str:
-    element = get_value(node.elt)
-    generators = [get_value(gen) for gen in node.generators]
+    element = _get_value(node.elt)
+    generators = [_get_value(gen) for gen in node.generators]
     return f"{element} " + " ".join(generators)
 
 
@@ -849,7 +971,7 @@ def _get_gt_value(node: NodeNotEq) -> str:
 
 
 def _get_ifexp_value(node: NodeIfExp) -> str:
-    return f"{get_value(node.body)} if {get_value(node.test)} else {get_value(node.orelse)}"
+    return f"{_get_value(node.body)} if {_get_value(node.test)} else {_get_value(node.orelse)}"
 
 
 def _get_invert_value(node: NodeInvert) -> str:
@@ -869,27 +991,27 @@ def _get_isnot_value(node: NodeIsNot) -> str:
 
 
 def _get_joinedstr_value(node: NodeJoinedStr) -> str:
-    _node_value_map[NodeConstant] = _get_constant_value_no_repr
-    result = repr("".join(get_value(value) for value in node.values))
+    _node_value_map[NodeConstant] = _get_constant_value_no_string_repr
+    result = "f" + repr("".join(_get_value(value) for value in node.values))
     _node_value_map[NodeConstant] = _get_constant_value
     return result
 
 
 def _get_keyword_value(node: NodeKeyword) -> str:
-    return f"{node.arg}={get_value(node.value)}"
+    return f"{node.arg}={_get_value(node.value)}"
 
 
 def _get_lambda_value(node: NodeLambda) -> str:
-    return f"lambda {get_value(node.args)}: {get_value(node.body)}"
+    return f"lambda {_get_value(node.args)}: {_get_value(node.body)}"
 
 
 def _get_list_value(node: NodeList) -> str:
-    return "[" + ", ".join(get_value(el) for el in node.elts) + "]"
+    return "[" + ", ".join(_get_value(el) for el in node.elts) + "]"
 
 
 def _get_listcomp_value(node: NodeListComp) -> str:
-    element = get_value(node.elt)
-    generators = [get_value(gen) for gen in node.generators]
+    element = _get_value(node.elt)
+    generators = [_get_value(gen) for gen in node.generators]
     return f"[{element} " + " ".join(generators) + "]"
 
 
@@ -946,24 +1068,24 @@ def _get_rshift_value(node: NodeRShift) -> str:
 
 
 def _get_set_value(node: NodeSet) -> str:
-    return "{" + ", ".join(get_value(el) for el in node.elts) + "}"
+    return "{" + ", ".join(_get_value(el) for el in node.elts) + "}"
 
 
 def _get_setcomp_value(node: NodeSetComp) -> str:
-    element = get_value(node.elt)
-    generators = [get_value(gen) for gen in node.generators]
+    element = _get_value(node.elt)
+    generators = [_get_value(gen) for gen in node.generators]
     return f"{{{element} " + " ".join(generators) + "}"
 
 
 def _get_slice_value(node: NodeSlice) -> str:
-    value = f"{get_value(node.lower) if node.lower else ''}:{get_value(node.upper) if node.upper else ''}"
+    value = f"{_get_value(node.lower) if node.lower else ''}:{_get_value(node.upper) if node.upper else ''}"
     if node.step:
-        value = f"{value}:{get_value(node.step)}"
+        value = f"{value}:{_get_value(node.step)}"
     return value
 
 
 def _get_starred_value(node: NodeStarred) -> str:
-    return get_value(node.value)
+    return _get_value(node.value)
 
 
 def _get_sub_value(node: NodeSub) -> str:
@@ -971,14 +1093,14 @@ def _get_sub_value(node: NodeSub) -> str:
 
 
 def _get_subscript_value(node: NodeSubscript) -> str:
-    subscript = get_value(node.slice)
-    if isinstance(subscript, str):
-        subscript = subscript.strip("()")
-    return f"{get_value(node.value)}[{subscript}]"
+    subscript = _get_value(node.slice)
+    if isinstance(subscript, str) and subscript.startswith("(") and subscript.endswith(")"):
+        subscript = subscript[1:-1]
+    return f"{_get_value(node.value)}[{subscript}]"
 
 
 def _get_tuple_value(node: NodeTuple) -> str:
-    return "(" + ", ".join(get_value(el) for el in node.elts) + ")"
+    return "(" + ", ".join(_get_value(el) for el in node.elts) + ")"
 
 
 def _get_uadd_value(node: NodeUAdd) -> str:
@@ -986,7 +1108,7 @@ def _get_uadd_value(node: NodeUAdd) -> str:
 
 
 def _get_unaryop_value(node: NodeUnaryOp) -> str:
-    return f"{get_value(node.op)}{get_value(node.operand)}"
+    return f"{_get_value(node.op)}{_get_value(node.operand)}"
 
 
 def _get_usub_value(node: NodeUSub) -> str:
@@ -996,11 +1118,11 @@ def _get_usub_value(node: NodeUSub) -> str:
 def _get_yield_value(node: NodeYield) -> str:
     if node.value is None:
         return repr(None)
-    return get_value(node.value)
+    return _get_value(node.value)
 
 
 _node_value_map: dict[Type, Callable[[Any], str]] = {
-    type(None): lambda _: repr(None),
+    # type(None): lambda _: repr(None),
     NodeAdd: _get_add_value,
     NodeAnd: _get_and_value,
     NodeArguments: _get_arguments_value,
@@ -1063,9 +1185,13 @@ _node_value_map: dict[Type, Callable[[Any], str]] = {
 # TODO: remove once Python 3.8 support is dropped
 if sys.version_info < (3, 9):
 
-    def _get_index_value(node: NodeIndex) -> str:
-        return get_value(node.value)
+    def _get_extslice_value(node: NodeExtSlice) -> str:
+        return ",".join(_get_value(dim) for dim in node.dims)
 
+    def _get_index_value(node: NodeIndex) -> str:
+        return _get_value(node.value)
+
+    _node_value_map[NodeExtSlice] = _get_extslice_value
     _node_value_map[NodeIndex] = _get_index_value
 
 
@@ -1090,18 +1216,45 @@ if sys.version_info < (3, 8):
     _node_value_map[NodeStr] = _get_str_value
 
 
-def get_value(node: AST) -> str:
-    """Extract a complex value as a string.
+def _get_value(node: AST) -> str:
+    return _node_value_map[type(node)](node)
+
+
+def get_value(node: AST | None) -> str | None:
+    """Unparse a node to its string representation.
 
     Parameters:
-        node: The node to extract the value from.
+        node: The node to unparse.
 
     Returns:
         The unparsed code of the node.
     """
+    if node is None:
+        return None
     return _node_value_map[type(node)](node)
 
 
+def safe_get_value(node: AST | None, filepath: str | Path | None = None) -> str | None:
+    """Safely (no exception) unparse a node to its string representation.
+
+    Parameters:
+        node: The node to unparse.
+        filepath: An optional filepath from where the node comes.
+
+    Returns:
+        The unparsed code of the node.
+    """
+    try:
+        return get_value(node)
+    except Exception as error:
+        message = f"Failed to unparse node {node}"
+        if filepath:
+            message += f" at {filepath}:{node.lineno}"  # type: ignore[union-attr]
+        message += f": {error}"
+        logger.error(message)
+        return None
+
+
 # ==========================================================
 # names
 def _get_attribute_name(node: NodeAttribute) -> str:
@@ -1172,7 +1325,7 @@ def get_instance_names(node: AST) -> list[str]:
 
 # ==========================================================
 # parameters
-def get_parameter_default(node: AST, filepath: Path, lines_collection: LinesCollection) -> str | None:
+def get_parameter_default(node: AST | None, filepath: Path, lines_collection: LinesCollection) -> str | None:
     """Extract the default value of a function parameter.
 
     Parameters:
@@ -1186,12 +1339,8 @@ def get_parameter_default(node: AST, filepath: Path, lines_collection: LinesColl
     """
     if node is None:
         return None
-    if isinstance(node, NodeConstant):
-        return repr(node.value)
-    if isinstance(node, NodeStr):
-        return repr(node.s)
-    if isinstance(node, NodeName):
-        return node.id
+    with suppress(KeyError):
+        return _get_value(node)
     if node.lineno == node.end_lineno:  # type: ignore[attr-defined]
         return lines_collection[filepath][node.lineno - 1][node.col_offset : node.end_col_offset]  # type: ignore[attr-defined]
     # TODO: handle multiple line defaults
