@@ -10,11 +10,10 @@ from __future__ import annotations
 
 import ast
 import inspect
-from collections import defaultdict
 from contextlib import suppress
 from itertools import zip_longest
 from pathlib import Path
-from typing import Any
+from typing import Any, Iterable
 
 from griffe.agents.base import BaseVisitor
 from griffe.agents.extensions import Extensions
@@ -25,9 +24,10 @@ from griffe.agents.nodes import (
     get_instance_names,
     get_names,
     get_parameter_default,
-    get_value,
     parse__all__,
     relative_to_absolute,
+    safe_get_annotation,
+    safe_get_value,
 )
 from griffe.collections import LinesCollection, ModulesCollection
 from griffe.dataclasses import (
@@ -48,17 +48,19 @@ from griffe.exceptions import LastNodeError, NameResolutionError
 from griffe.expressions import Expression, Name
 
 builtin_decorators = {
-    "property",
-    "staticmethod",
-    "classmethod",
+    "property": "property",
+    "staticmethod": "staticmethod",
+    "classmethod": "classmethod",
 }
 
 stdlib_decorators = {
-    "abc.abstractmethod",
-    "functools.cache",
-    "functools.cached_property",
-    "functools.lru_cache",
+    "abc.abstractmethod": {"abstractmethod"},
+    "functools.cache": {"cached"},
+    "functools.cached_property": {"cached", "property"},
+    "functools.lru_cache": {"cached"},
+    "dataclasses.dataclass": {"dataclass"},
 }
+typing_overload = {"typing.overload", "typing_extensions.overload"}
 
 
 def visit(
@@ -145,7 +147,6 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         self.lines_collection: LinesCollection = lines_collection or LinesCollection()
         self.modules_collection: ModulesCollection = modules_collection or ModulesCollection()
         self.type_guarded: bool = False
-        self.overloads: dict[str, list[Function]] = defaultdict(list)
 
     def _get_docstring(self, node: ast.AST, strict: bool = False) -> Docstring | None:
         value, lineno, endlineno = get_docstring(node, strict=strict)
@@ -227,7 +228,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             for decorator_node in node.decorator_list:
                 decorators.append(
                     Decorator(
-                        get_value(decorator_node),
+                        safe_get_value(decorator_node, self.current.relative_filepath),  # type: ignore[arg-type]
                         lineno=decorator_node.lineno,
                         endlineno=decorator_node.end_lineno,  # type: ignore[attr-defined]
                     )
@@ -239,7 +240,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         bases = []
         if node.bases:
             for base in node.bases:
-                bases.append(get_annotation(base, self.current))
+                bases.append(safe_get_annotation(base, parent=self.current))
 
         class_ = Class(
             name=node.name,
@@ -250,6 +251,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             bases=bases,  # type: ignore[arg-type]
             runtime=not self.type_guarded,
         )
+        class_.labels |= self.decorators_to_labels(decorators)
         self.current[node.name] = class_
         self.current = class_
         self.generic_visit(node)
@@ -268,17 +270,14 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         for decorator in decorators:
             decorator_value = decorator.value.split("(", 1)[0]
             if decorator_value in builtin_decorators:
-                labels.add(decorator_value)
+                labels.add(builtin_decorators[decorator_value])
             else:
                 names = decorator_value.split(".")
                 with suppress(NameResolutionError):
                     resolved_first = self.current.resolve(names[0])
                     resolved_name = ".".join([resolved_first, *names[1:]])
                     if resolved_name in stdlib_decorators:
-                        if "abstract" in resolved_name:
-                            labels.add("abstract")
-                        elif "cache" in resolved_name:
-                            labels.add("cached")
+                        labels |= stdlib_decorators[resolved_name]
         return labels
 
     def get_base_property(self, decorators: list[Decorator]) -> tuple[Function | None, str | None]:
@@ -319,15 +318,15 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         if node.decorator_list:
             lineno = node.decorator_list[0].lineno
             for decorator_node in node.decorator_list:
-                decorator_value = get_value(decorator_node)
+                decorator_value = safe_get_value(decorator_node, self.filepath)
                 overload = (
-                    decorator_value == "typing.overload"
+                    decorator_value in typing_overload
                     or decorator_value == "overload"
-                    and self.current.resolve("overload") == "typing.overload"
+                    and self.current.resolve("overload") in typing_overload
                 )
                 decorators.append(
                     Decorator(
-                        decorator_value,
+                        decorator_value,  # type: ignore[arg-type]
                         lineno=decorator_node.lineno,
                         endlineno=decorator_node.end_lineno,  # type: ignore[attr-defined]
                     )
@@ -349,7 +348,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             posonlyargs = []
 
         # TODO: probably some optimizations to do here
-        args_kinds_defaults = reversed(
+        args_kinds_defaults: Iterable = reversed(
             (
                 *zip_longest(  # noqa: WPS356
                     reversed(
@@ -367,16 +366,19 @@ class Visitor(BaseVisitor):  # noqa: WPS338
                 ),
             )
         )
-        for (arg, kind), default in args_kinds_defaults:
-            annotation = get_annotation(arg.annotation, parent=self.current)
-            default = get_parameter_default(default, self.filepath, self.lines_collection)
+        arg: ast.arg
+        kind: ParameterKind
+        arg_default: ast.AST | None
+        for (arg, kind), arg_default in args_kinds_defaults:
+            annotation = safe_get_annotation(arg.annotation, parent=self.current)
+            default = get_parameter_default(arg_default, self.filepath, self.lines_collection)
             parameters.add(Parameter(arg.arg, annotation=annotation, kind=kind, default=default))
 
         if node.args.vararg:
-            annotation = get_annotation(node.args.vararg.annotation, parent=self.current)
+            annotation = safe_get_annotation(node.args.vararg.annotation, parent=self.current)
             parameters.add(
                 Parameter(
-                    f"*{node.args.vararg.arg}",
+                    node.args.vararg.arg,
                     annotation=annotation,
                     kind=ParameterKind.var_positional,
                     default="()",
@@ -384,7 +386,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             )
 
         # TODO: probably some optimizations to do here
-        kwargs_defaults = reversed(
+        kwargs_defaults: Iterable = reversed(
             (
                 *zip_longest(  # noqa: WPS356
                     reversed(node.args.kwonlyargs),
@@ -393,18 +395,20 @@ class Visitor(BaseVisitor):  # noqa: WPS338
                 ),
             )
         )
-        for kwarg, default in kwargs_defaults:  # noqa: WPS440
-            annotation = get_annotation(kwarg.annotation, parent=self.current)
-            default = get_parameter_default(default, self.filepath, self.lines_collection)
+        kwarg: ast.arg
+        kwarg_default: ast.AST | None
+        for kwarg, kwarg_default in kwargs_defaults:  # noqa: WPS440
+            annotation = safe_get_annotation(kwarg.annotation, parent=self.current)
+            default = get_parameter_default(kwarg_default, self.filepath, self.lines_collection)
             parameters.add(
                 Parameter(kwarg.arg, annotation=annotation, kind=ParameterKind.keyword_only, default=default)
             )
 
         if node.args.kwarg:
-            annotation = get_annotation(node.args.kwarg.annotation, parent=self.current)
+            annotation = safe_get_annotation(node.args.kwarg.annotation, parent=self.current)
             parameters.add(
                 Parameter(
-                    f"**{node.args.kwarg.arg}",
+                    node.args.kwarg.arg,
                     annotation=annotation,
                     kind=ParameterKind.var_keyword,
                     default="{}",  # noqa: P103
@@ -416,7 +420,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             lineno=lineno,
             endlineno=node.end_lineno,  # type: ignore[union-attr]
             parameters=parameters,
-            returns=get_annotation(node.returns, parent=self.current),
+            returns=safe_get_annotation(node.returns, parent=self.current),
             decorators=decorators,
             docstring=self._get_docstring(node),
             runtime=not self.type_guarded,
@@ -424,7 +428,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         )
 
         if overload:
-            self.overloads[function.path].append(function)
+            self.current.overloads[function.name].append(function)
         elif base_property is not None:
             if property_function == "setter":
                 base_property.setter = function
@@ -434,8 +438,9 @@ class Visitor(BaseVisitor):  # noqa: WPS338
                 base_property.labels.add("deletable")
         else:
             self.current[node.name] = function
-            if self.overloads[function.path]:
-                function.overloads = self.overloads[function.path]
+            if self.current.kind in {Kind.MODULE, Kind.CLASS} and self.current.overloads[function.name]:
+                function.overloads = self.current.overloads[function.name]
+                del self.current.overloads[function.name]  # noqa: WPS420
 
         function.labels |= labels
 
@@ -547,7 +552,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         if not names:
             return
 
-        value = get_value(node.value)  # type: ignore[arg-type]
+        value = safe_get_value(node.value, self.filepath)  # type: ignore[arg-type]
 
         try:
             docstring = self._get_docstring(node.next, strict=True)  # type: ignore[union-attr]
@@ -580,7 +585,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
 
             if name == "__all__":
                 with suppress(AttributeError):
-                    parent.exports = parse__all__(node)  # type: ignore[arg-type]
+                    parent.exports = parse__all__(node, self.current)  # type: ignore[assignment,arg-type]
 
     def visit_assign(self, node: ast.Assign) -> None:
         """Visit an assignment node.
@@ -596,7 +601,23 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         Parameters:
             node: The node to visit.
         """
-        self.handle_attribute(node, get_annotation(node.annotation, parent=self.current))
+        self.handle_attribute(node, safe_get_annotation(node.annotation, parent=self.current))
+
+    def visit_augassign(self, node: ast.AugAssign) -> None:
+        """Visit an augmented assignment node.
+
+        Parameters:
+            node: The node to visit.
+        """
+        with suppress(AttributeError):
+            all_augment = (
+                node.target.id == "__all__"  # type: ignore[attr-defined]
+                and self.current.is_module
+                and isinstance(node.op, ast.Add)
+            )
+            if all_augment:
+                # we assume exports is not None at this point
+                self.current.exports.extend(parse__all__(node, self.current))  # type: ignore[arg-type,union-attr]
 
     def visit_if(self, node: ast.If) -> None:
         """Visit an "if" node.
@@ -606,7 +627,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         """
         if isinstance(node.parent, (ast.Module, ast.ClassDef)):  # type: ignore[attr-defined]
             with suppress(KeyError):  # unhandled AST nodes
-                condition = get_annotation(node.test, self.current)
+                condition = get_annotation(node.test, parent=self.current)
                 if str(condition) in {"typing.TYPE_CHECKING", "TYPE_CHECKING"}:
                     self.type_guarded = True
         self.generic_visit(node)
