@@ -206,6 +206,21 @@ class Parameter:
         self.kind: ParameterKind | None = kind
         self.default: str | None = default
 
+    def __str__(self) -> str:
+        param = f"{self.name}: {self.annotation} = {self.default}"
+        if self.kind:
+            return f"[{self.kind.value}] {param}"
+        return param
+
+    @property
+    def required(self) -> bool:
+        """Tell if this parameter is required.
+
+        Returns:
+            True or False.
+        """
+        return self.default is None
+
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:
         """Return this parameter's data as a dictionary.
 
@@ -243,7 +258,7 @@ class Parameters:
     def __getitem__(self, name_or_index: int | str) -> Parameter:
         if isinstance(name_or_index, int):
             return self._parameters_list[name_or_index]
-        return self._parameters_dict[name_or_index]
+        return self._parameters_dict[name_or_index.lstrip("*")]
 
     def __len__(self):
         return len(self._parameters_list)
@@ -252,7 +267,7 @@ class Parameters:
         return iter(self._parameters_list)
 
     def __contains__(self, param_name: str):
-        return param_name in self._parameters_dict
+        return param_name.lstrip("*") in self._parameters_dict
 
     def add(self, parameter: Parameter) -> None:
         """Add a parameter to the container.
@@ -885,7 +900,7 @@ class Alias(ObjectAliasMixin):
     def parent(self, value: Module | Class) -> None:
         self._parent = value
         if self.resolved:
-            with suppress(AliasResolutionError):
+            with suppress(AliasResolutionError, CyclicAliasError):
                 self._target.aliases[self.path] = self  # type: ignore[union-attr]  # we just checked the target is not None
 
     @cached_property
@@ -923,7 +938,7 @@ class Alias(ObjectAliasMixin):
 
     @target.setter
     def target(self, value: Object | Alias) -> None:
-        if value is self:
+        if value is self or value.path == self.path:
             raise CyclicAliasError([self.target_path])
         self._target = value
         self.target_path = value.path
@@ -958,7 +973,7 @@ class Alias(ObjectAliasMixin):
         Returns:
             True or False.
         """
-        return self._target is not None
+        return self._target is not None and (not self._target.is_alias or self._target.resolved)  # type: ignore[union-attr]
 
     @cached_property
     def wildcard(self) -> str | None:
