@@ -67,6 +67,7 @@ from griffe.docstrings.dataclasses import (
 )
 from griffe.docstrings.utils import parse_annotation, warning
 from griffe.expressions import Expression, Name
+from griffe.logger import LogLevel
 
 if TYPE_CHECKING:
     from typing import Any, Literal, Pattern  # type: ignore[attr-defined]
@@ -170,10 +171,10 @@ def _read_block(docstring: Docstring, offset: int) -> tuple[str, int]:  # noqa:
         new_offset += 1
     while new_offset < len(lines):
         is_empty = _is_empty_line(lines[new_offset])
-        if is_empty and _is_dash_line(lines[new_offset + 1]):
+        if is_empty and new_offset < len(lines) - 1 and _is_dash_line(lines[new_offset + 1]):
             break  # Break if a new unnamed section is reached.
 
-        if is_empty and new_offset < len(lines) + 1 and _is_dash_line(lines[new_offset + 2]):
+        if is_empty and new_offset < len(lines) - 2 and _is_dash_line(lines[new_offset + 2]):
             break  # Break if a new named section is reached.
 
         block.append(lines[new_offset])
@@ -253,7 +254,7 @@ def _read_parameters(  # noqa: WPS231
             else:
                 _warn(docstring, new_offset, f"No types or annotations for parameters {names}")
         else:
-            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
+            annotation = parse_annotation(annotation, docstring, log_level=LogLevel.debug)  # type: ignore[arg-type]
 
         if default is None:
             for name in names:  # noqa: WPS440
@@ -375,7 +376,7 @@ def _read_returns_section(  # noqa: WPS231
                         else:
                             annotation = return_item
         else:
-            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
+            annotation = parse_annotation(annotation, docstring, log_level=LogLevel.debug)  # type: ignore[arg-type]
         returns.append(DocstringReturn(name=name or "", annotation=annotation, description=text))
     return DocstringSectionReturns(returns), new_offset
 
@@ -422,7 +423,7 @@ def _read_yields_section(  # noqa: WPS231
                     else:
                         annotation = yield_item
         else:
-            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
+            annotation = parse_annotation(annotation, docstring, log_level=LogLevel.debug)  # type: ignore[arg-type]
         yields.append(DocstringYield(name=name or "", annotation=annotation, description=text))
     return DocstringSectionYields(yields), new_offset
 
@@ -464,7 +465,7 @@ def _read_receives_section(  # noqa: WPS231
                     else:
                         annotation = receives_item
         else:
-            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
+            annotation = parse_annotation(annotation, docstring, log_level=LogLevel.debug)  # type: ignore[arg-type]
         receives.append(DocstringReceive(name=name or "", annotation=annotation, description=text))
     return DocstringSectionReceives(receives), new_offset
 
@@ -542,7 +543,7 @@ def _read_attributes_section(
             with suppress(AttributeError, KeyError):
                 annotation = docstring.parent.members[name].annotation  # type: ignore[union-attr]
         else:
-            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
+            annotation = parse_annotation(annotation, docstring, log_level=LogLevel.debug)  # type: ignore[arg-type]
         text = dedent("\n".join(item[1:]))
         attributes.append(DocstringAttribute(name=name, annotation=annotation, description=text))
     return DocstringSectionAttributes(attributes), new_offset
