@@ -2,6 +2,8 @@
 
 from __future__ import annotations
 
+import logging
+
 import pytest
 
 from griffe.dataclasses import Attribute, Class, Docstring, Function, Module, Parameter, Parameters
@@ -172,20 +174,42 @@ def test_parse_annotations_in_all_sections(parse_numpy, docstring, name):
     assert sections[0].value[0].annotation == Name(name, name)
 
 
-# https://github.com/mkdocstrings/mkdocstrings/issues/416
-def test_dont_crash_on_text_annotations(parse_numpy):
+def test_dont_crash_on_text_annotations(parse_numpy, caplog):
     """Don't crash while parsing annotations containing unhandled nodes.
 
     Parameters:
         parse_numpy: Fixture parser.
+        caplog: Pytest fixture used to capture logs.
     """
     docstring = """
+        Attributes
+        ----------
+        region : str, list-like, geopandas.GeoSeries, geopandas.GeoDataFrame, geometric
+            Description.
+
         Parameters
         ----------
         region : str, list-like, geopandas.GeoSeries, geopandas.GeoDataFrame, geometric
             Description.
+
+        Returns
+        -------
+        str or bytes
+            Description.
+
+        Receives
+        --------
+        region : str, list-like, geopandas.GeoSeries, geopandas.GeoDataFrame, geometric
+            Description.
+
+        Yields
+        ------
+        str or bytes
+            Description.
     """
+    caplog.set_level(logging.DEBUG)
     assert parse_numpy(docstring, parent=Function("f"))
+    assert all(record.levelname == "DEBUG" for record in caplog.records if "Failed to parse" in record.message)
 
 
 # =============================================================================================
@@ -477,7 +501,7 @@ def test_examples_section(parse_numpy):
 
 
 def test_examples_section_when_followed_by_named_section(parse_numpy):
-    """Parse examples section.
+    """Parse examples section followed by another section.
 
     Parameters:
         parse_numpy: Parse function (fixture).
@@ -498,6 +522,30 @@ def test_examples_section_when_followed_by_named_section(parse_numpy):
     assert sections[1].kind is DocstringSectionKind.parameters
 
 
+def test_examples_section_as_last(parse_numpy):
+    """Parse examples section being last in the docstring.
+
+    Parameters:
+        parse_numpy: Parse function (fixture).
+    """
+    docstring = """
+        Lorem ipsum dolor sit amet, consectetur adipiscing elit...
+
+        Examples
+        --------
+        ```python
+        >>> LoremIpsum.from_string("consectetur")
+        <foofoo: Ipsum.Lorem>
+
+        ```
+    """
+
+    sections, _ = parse_numpy(docstring)
+    assert len(sections) == 2
+    assert sections[0].kind is DocstringSectionKind.text
+    assert sections[1].kind is DocstringSectionKind.examples
+
+
 # =============================================================================================
 # Attributes sections
 def test_retrieve_attributes_annotation_from_parent(parse_numpy):
