@@ -18,58 +18,6 @@ from tests.helpers import temporary_pypackage, temporary_visited_module
 #         ...
 
 
-# TODO: move this in test_nodes once hypothesmith is ready
-@pytest.mark.parametrize(
-    "expression",
-    [
-        # operations
-        "b + c",
-        "b - c",
-        "b * c",
-        "b / c",
-        "b // c",
-        "b ** c",
-        "b ^ c",
-        "b & c",
-        "b | c",
-        "b @ c",
-        "b % c",
-        "b >> c",
-        "b << c",
-        # unary operations
-        "+b",
-        "-b",
-        "~b",
-        # comparisons
-        "b == c",
-        "b >= c",
-        "b > c",
-        "b <= c",
-        "b < c",
-        "b != c",
-        # boolean logic
-        "b and c",
-        "b or c",
-        "not b",
-        # identify
-        "b is c",
-        "b is not c",
-        # membership
-        "b in c",
-        "b not in c",
-    ],
-)
-def test_building_value_from_nodes(expression):
-    """Test building value from AST nodes.
-
-    Parameters:
-        expression: An expression (parametrized).
-    """
-    with temporary_visited_module(f"a = {expression}") as module:
-        assert "a" in module.members
-        assert module["a"].value == expression
-
-
 def test_not_defined_at_runtime():
     """Assert that objects not defined at runtime are not added to wildcards expansions."""
     with temporary_pypackage("package", ["module_a.py", "module_b.py", "module_c.py"]) as tmp_package:
@@ -277,3 +225,38 @@ def test_parse_complex__all__assignments(statements):
         loader.resolve_aliases()
 
         assert package.exports == {"CONST_INIT", "CONST_A", "CONST_B", "CONST_C"}
+
+
+def test_dont_crash_on_nested_functions_in_init():
+    """Assert we don't crash when visiting a nested function in `__init__` methods."""
+    with temporary_visited_module(
+        """
+        class C:
+            def __init__(self):
+                def pl(i: int):
+                    return i + 1
+        """
+    ) as module:
+        assert module
+
+
+def test_get_correct_docstring_starting_line_number():
+    """Assert we get the correct line numbers for docstring, even on Python 3.7."""
+    with temporary_visited_module(
+        """
+        '''
+        Module docstring.
+        '''
+        class C:
+            '''
+            Class docstring.
+            '''
+            def method(self):
+                '''
+                Method docstring.
+                '''
+        """
+    ) as module:
+        assert module.docstring.lineno == 2
+        assert module["C"].docstring.lineno == 6
+        assert module["C.method"].docstring.lineno == 10
